import json
from decimal import Decimal

import requests

from pricehist.price import Price


class CoinDesk:
    def id(self):
        return "coindesk"

    def name(self):
        return "CoinDesk Bitcoin Price Index"

    def description(self):
        return (
            "An average of bitcoin prices across leading global exchanges. \n"
            "Powered by CoinDesk, https://www.coindesk.com/price/bitcoin"
        )

    def source_url(self):
        return "https://www.coindesk.com/coindesk-api"

    def start(self):
        return "2010-07-17"

    def types(self):
        return ["close"]

    def notes(self):
        return ""

    def symbols(self):
        url = "https://api.coindesk.com/v1/bpi/supported-currencies.json"
        response = requests.get(url)
        data = json.loads(response.content)
        relevant = [i for i in data if i["currency"] not in ["XBT", "BTC"]]
        symbols = sorted(
            [f"BTC/{i['currency']}    Bitcoin against {i['country']}" for i in relevant]
        )
        return symbols

    def fetch(self, pair, type, start, end):
        base, quote = pair.split("/")

        url = "https://api.coindesk.com/v1/bpi/historical/close.json"
        params = {
            "currency": quote,
            "start": start,
            "end": end,
        }
        response = requests.get(url, params=params)
        data = json.loads(response.content)
        prices = []
        for (d, v) in data["bpi"].items():
            prices.append(Price(base, quote, d, Decimal(str(v))))

        return prices
